@@ -19,27 +19,49 @@ class UpdateStateMessage(AvatarMessage):
 
 class BreakpointHitMessage(UpdateStateMessage):
     def __init__(self, origin, breakpoint_number, address):
-        super(self.__class__, self).__init__(origin, TargetStates.STOPPED)
+        super(BreakpointHitMessage, self).__init__(origin, TargetStates.BREAKPOINT)
         self.breakpoint_number = breakpoint_number
         self.address = address
 
+class SyscallCatchedMessage(BreakpointHitMessage):
+    def __init__(self, origin, breakpoint_number, address, type='entry'):
+        super(self.__class__, self).__init__(origin, breakpoint_number, address)
+        self.type = type
+
 
 class RemoteMemoryReadMessage(AvatarMessage):
-    def __init__(self, origin, id, pc, address, size):
+    def __init__(self, origin, id, pc, address, size, dst=None):
         super(self.__class__, self).__init__(origin)
         self.id = id
         self.pc = pc
         self.address = address
         self.size = size
-
+        self.dst = dst
+        self.num_words = 1
+        self.raw = False
 
 class RemoteMemoryWriteMessage(AvatarMessage):
-    def __init__(self, origin, id, pc, address, value, size):
+    def __init__(self, origin, id, pc, address, value, size, dst=None):
         super(self.__class__, self).__init__(origin)
         self.id = id
         self.pc = pc
         self.address = address
         self.value = value
         self.size = size
+        self.dst = dst
+
+class RemoteInterruptEnterMessage(AvatarMessage):
+    def __init__(self, origin, id, interrupt_num):
+        super(self.__class__, self).__init__(origin)
+        self.id = id
+        self.interrupt_num = interrupt_num
+
+class RemoteInterruptExitMessage(AvatarMessage):
+    def __init__(self, origin, id, transition_type, interrupt_num):
+        super(self.__class__, self).__init__(origin)
+        self.id = id
+        self.transition_type = transition_type
+        self.interrupt_num = interrupt_num
+
 
 from .targets.target import TargetStates
